##  Cross-Checking the Discovered Services
If needed, you can cross-check the discovered SaaS in SAP LeanIX with those listed in WalkMe.
  1. Navigate to WalkMe Admin Center → Discovery → Apps.
  2. In the date filter above, select the previous month to view the corresponding list.
![Cross-Checking the Discovered Services in WalkMe](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748dab07a441014a78cfa9fad00cdf1_LowRes.png)
Cross-Checking the Discovered Services in WalkMe
